@@ -21,7 +21,11 @@ try:
     import gobject
     import pygst
     pygst.require('0.10')
+    # http://29a.ch/tags/pygst
+    argv = sys.argv
+    sys.argv = []
     import gst
+    sys.argv = argv
 except ImportError:
     HAVE_GST = False
 else:
@@ -83,22 +87,6 @@ class GstVideoOpener(object):
                 raise TranscodeError(message.parse_error())
 
 
-class GstVideoInspector(GstVideoOpener):
-
-    def __init__(self):
-        super(GstVideoInspector, self).__init__()
-
-        fakesink = gst.element_factory_make("fakesink")
-        self.pipeline.add(fakesink)
-        self.decode.link(fakesink)
-
-    def inspect(self, file_path):
-        self.open(file_path)
-
-        props = {}
-        return props
-
-
 class GstVideoConverter(GstVideoOpener):
 
     def __init__(self):
@@ -190,33 +178,13 @@ class OggTheoraTranscoder(GstVideoConverter):
         self.oggmux.link(self.oqueue)
 
 
-class VideoThumbnailer(GstVideoConverter):
-
-    def __init__(self):
-        super(VideoThumbnailer, self).__init__()
-
-        # Working pipeline
-        # gst-launch-0.10 filesrc location=surf_luge.mov num-buffers=1
-        # ! decodebin ! queue ! ffmpegcolorspace ! jpegenc
-        # ! filesink location=surf_luge_thumb.jpg sync=false
-        # other :
-        # decodebin2 ! videoscale ! video/x-raw-yuv,width=160,height=160 !
-        # jpegenc name=enc
-
-        # Video
-        self.decode_video()
-
-
 if __name__ == '__main__':
     import sys, os
     converter = OggTheoraConverter()
-    thumbnailer = VideoThumbnailer()
     for file_path in sys.argv[1:]:
         fn, ext = os.path.splitext(file_path)
         ogg_path = fn + '.ogg'
         converter.convert(file_path, ogg_path)
-        thumb_path = fn + '_thumb.jpg'
-        thumbnailer.convert(file_path, thumb_path)
 
 
 # vim: ts=4 sw=4 expandtab
