@@ -16,6 +16,7 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 import os, sys, datetime, locale
+import codecs
 import Image
 
 import pyexiv2
@@ -73,13 +74,13 @@ class _ImageInfoTags(object):
         vendors put different information to both tags.
         '''
         try:
-            model = str(self._metadata['Exif.Image.Model']).strip()
+            model = self.get_tag_value('Exif.Image.Model').strip()
             # Terminate string at \x00
             pos = model.find('\x00')
             if pos != -1:
                 model = model[:14]
             try:
-                vendor = str(self._metadata['Exif.Image.Make']).strip()
+                vendor = self.get_tag_value('Exif.Image.Make').strip()
                 vendor_l = vendor.lower()
                 model_l = model.lower()
                 # Split vendor to words and check whether they are
@@ -197,9 +198,11 @@ class _ImageInfoTags(object):
         except (ValueError, KeyError):
             try:
                 ret = self.get_exif_string('Exif.Image.ImageDescription')
+                ret = self._fallback_to_encoding(ret)
             except (ValueError, KeyError):
                 try:
                     ret = self.get_exif_string('Iptc.Application2.ObjectName')
+                    ret = self._fallback_to_encoding(ret)
                 except (ValueError, KeyError):
                     ret = self.get_jpeg_comment()
         return ret
@@ -481,9 +484,9 @@ class DefaultMetadata(make.FileMakeObject):
         md_data = md.get()
         if 'album_description' in md_data.keys()\
         or 'album_name' in md_data.keys():
-            self.log(_("  SKIPPED because metadata exists."))
+            self.album.log(_("  SKIPPED because metadata exists."))
         elif self.source_dir.get_all_medias_count() < 1:
-            self.log(_("  SKIPPED because directory does not contain images."))
+            self.album.log(_("  SKIPPED because directory does not contain images."))
         else:
             self.generate(md_data)
 
@@ -495,10 +498,13 @@ class DefaultMetadata(make.FileMakeObject):
         self.album.log(_("GEN %s") % self._path, 'info')
 
         f = file(self._path, 'w')
+        f.write(codecs.BOM_UTF8)
         f.write('# Directory metadata for lazygal, Matew format\n')
-        f.write('Album name "%s"\n' % self.source_dir.human_name);
+        f.write('Album name "%s"\n'\
+                % self.source_dir.human_name.encode('utf-8'));
         f.write('Album description ""\n');
-        f.write('Album image identifier "%s"\n' % md['album_picture']);
+        f.write('Album image identifier "%s"\n'\
+                % md['album_picture'].encode('utf-8'));
         f.close()
 
 
